.. :changelog:

History
-------

0.5 2013-10-17
++++++++++++++

* Released to PyPI

0.4 2013-10-17
++++++++++++++

* Fixed crash when multiple changes detected and first triggers restart (`#6`_)

* Fixed default mode always closing FDs (`#5`_)


0.3 2013-10-16
++++++++++++++

* Added ability to specify restart command (`#1`_)

* Added ability to cancel the restart (`#2`_)

0.1 2013-10-15
++++++++++++++

* First functional release.

.. _#6: https://github.com/nbargnesi/lazarus/issues/6
.. _#5: https://github.com/nbargnesi/lazarus/issues/5
.. _#2: https://github.com/nbargnesi/lazarus/issues/2
.. _#1: https://github.com/nbargnesi/lazarus/issues/1

